NAME

AmberDB::Locale::Lang::de - German Language Definition and Locale Data for AmberDB

SYNOPSIS

use AmberDB::Locale;
my $loc = AmberDB::Locale->new('de');

DESCRIPTION

Provides German (de) casing, character maps, number/currency formats, date templates, and plural rules for the AmberDB locale engine.

AUTHOR

Maruf Cetin <marufcetin@gmail.com>

LICENSE AND COPYRIGHT

Copyright (C) 2026 Maruf Cetin.

This library is free software; you can redistribute it and/or modify it under the terms of the Artistic License 2.0.