NAME
AmberDB::Locale::Lang::ja - Japanese Language Definition and Locale Data for AmberDB
SYNOPSIS
use AmberDB::Locale;
my $loc = AmberDB::Locale->new('ja');
DESCRIPTION
Provides Japanese (ja) character maps, number/currency formats, date templates, and plural rules for the AmberDB locale engine.
AUTHOR
Maruf Cetin <marufcetin@gmail.com>
LICENSE AND COPYRIGHT
Copyright (C) 2026 Maruf Cetin.
This library is free software; you can redistribute it and/or modify it under the terms of the Artistic License 2.0.